summaryrefslogtreecommitdiff
path: root/sys
diff options
context:
space:
mode:
Diffstat (limited to 'sys')
-rw-r--r--sys/dev/ic/if_wi.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/sys/dev/ic/if_wi.c b/sys/dev/ic/if_wi.c
index 897ad56e355..792a7198456 100644
--- a/sys/dev/ic/if_wi.c
+++ b/sys/dev/ic/if_wi.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: if_wi.c,v 1.113 2004/11/23 21:12:23 fgsch Exp $ */
+/* $OpenBSD: if_wi.c,v 1.114 2004/12/22 02:19:11 millert Exp $ */
/*
* Copyright (c) 1997, 1998, 1999
@@ -127,7 +127,7 @@ u_int32_t widebug = WIDEBUG;
#if !defined(lint) && !defined(__OpenBSD__)
static const char rcsid[] =
- "$OpenBSD: if_wi.c,v 1.113 2004/11/23 21:12:23 fgsch Exp $";
+ "$OpenBSD: if_wi.c,v 1.114 2004/12/22 02:19:11 millert Exp $";
#endif /* lint */
#ifdef foo
@@ -1026,9 +1026,9 @@ wi_cor_reset(sc)
* Do a soft reset of the card; this is required for Symbol cards.
* This shouldn't hurt other cards but there have been reports
* of the COR reset messing up old Lucent firmware revisions so
* we only soft reset Symbol cards for now.
*/
- if (sc->sc_firmware_type == WI_SYMBOL) {
+ if (sc->sc_firmware_type != WI_LUCENT) {
cor_value = bus_space_read_1(sc->wi_ltag, sc->wi_lhandle,
sc->wi_cor_offset);
bus_space_write_1(sc->wi_ltag, sc->wi_lhandle,
@@ -1026,9 +1026,9 @@ wi_cor_reset(sc)
* This shouldn't hurt other cards but there have been reports
* of the COR reset messing up old Lucent firmware revisions so
- * we only soft reset Symbol cards for now.
+ * we avoid soft reset on Lucent cards for now.
*/